@@ -10,12 +10,11 @@ from rest_framework.request import Request
 from rest_framework.response import Response
 from django.core.exceptions import ValidationError
 from django.utils.translation import gettext as _
-from django.conf import settings as django_settings
 from django.urls import reverse
+from django.conf import settings as django_settings
 
 from polaris import settings
 from polaris.utils import getLogger
-from polaris.middleware import import_path
 from polaris.models import Asset, Transaction
 from polaris.utils import render_error_response, verify_valid_asset_operation
 
@@ -97,6 +96,15 @@ def authenticate_session_helper(r: Request):
                 return
         else:
             raise ValueError("Missing authentication token")
+    elif r.session.exists(r.session.session_key) and token in r.session.get(
+        "tokens", []
+    ):
+        # The client opened an interactive flow with a specific token for the second time
+        raise ValueError("Unexpected one-time auth token")
+    elif r.session.get("tokens"):
+        r.session["tokens"].append(token)
+    else:
+        r.session["tokens"] = [token]
 
     try:
         jwt_dict = jwt.decode(token, settings.SERVER_JWT_KEY, algorithms=["HS256"])
