@@ -31,22 +31,24 @@ def fixture_usd_asset_factory():
         Creates a test USD asset that composes the example /info response, according
         to https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0024.md#response-2
         """
+        signer = {
+            "key": Keypair.from_secret(USD_DISTRIBUTION_SEED).public_key,
+            "weight": 1,
+            "type": "ed25519_public_key",
+        }
         if not protocols:
             protocols = [Transaction.PROTOCOL.sep24]
         usd_asset = Asset(
             code="USD",
             issuer=USD_ISSUER_ACCOUNT,
             distribution_seed=USD_DISTRIBUTION_SEED,
-            distribution_account_signers=json.dumps(
-                {
-                    "key": Keypair.from_secret(USD_DISTRIBUTION_SEED).public_key,
-                    "weight": 1,
-                    "type": "ed25519_public_key",
-                }
-            ),
-            distribution_account_thresholds=json.dumps(
-                {"low_threshold": 0, "med_threshold": 1, "high_threshold": 1}
-            ),
+            distribution_account_signers=[signer],
+            distribution_account_thresholds={
+                "low_threshold": 0,
+                "med_threshold": 1,
+                "high_threshold": 1,
+            },
+            distribution_account_master_signer=signer,
             significant_decimals=2,
             # Deposit Info
             deposit_enabled=True,
@@ -79,10 +81,10 @@ def fixture_usd_asset_factory():
 def fixture_no_asset_distribution_account_updates():
     from polaris import models
 
-    models.hidden_update_distribution_account_data = (
-        models.update_distribution_account_data
-    )
-    models.update_distribution_account_data = Mock()
+    tmp = models.Asset.load_distribution_account_data
+    models.Asset.load_distribution_account_data = Mock()
+    yield  # run tests, then in cleanup:
+    models.Asset.load_distribution_account_data = tmp
 
 
 @pytest.fixture(scope="session", name="eth_asset_factory")
@@ -94,22 +96,24 @@ def fixture_eth_asset_factory():
         Creates a test ETH asset that composes the example /info response, according
         to https://github.com/stellar/stellar-protocol/blob/master/ecosystem/sep-0024.md#response-2
         """
+        signer = {
+            "key": Keypair.from_secret(ETH_DISTRIBUTION_SEED).public_key,
+            "weight": 1,
+            "type": "ed25519_public_key",
+        }
         if not protocols:
             protocols = [Transaction.PROTOCOL.sep24]
         eth_asset = Asset(
             code="ETH",
             issuer=ETH_ISSUER_ACCOUNT,
             distribution_seed=ETH_DISTRIBUTION_SEED,
-            distribution_account_signers=json.dumps(
-                {
-                    "key": Keypair.from_secret(USD_DISTRIBUTION_SEED).public_key,
-                    "weight": 1,
-                    "type": "ed25519_public_key",
-                }
-            ),
-            distribution_account_thresholds=json.dumps(
-                {"low_threshold": 0, "med_threshold": 1, "high_threshold": 1}
-            ),
+            distribution_account_signers=[signer],
+            distribution_account_thresholds={
+                "low_threshold": 0,
+                "med_threshold": 1,
+                "high_threshold": 1,
+            },
+            distribution_account_master_signer=signer,
             # Deposit Info
             deposit_enabled=True,
             deposit_fee_fixed=0.002,
